@@ -1,6 +1,6 @@
 package Yukki::Model::File;
 BEGIN {
-  $Yukki::Model::File::VERSION = '0.111060';
+  $Yukki::Model::File::VERSION = '0.111160';
 }
 use 5.12.1;
 use Moose;
@@ -202,6 +202,35 @@ sub fetch {
 }
 
 
+sub has_format {
+    my ($self, $media_type) = @_;
+
+    my @formatters = $self->app->formatter_plugins;
+    for my $formatter (@formatters) {
+        return 1 if $formatter->has_format($media_type);
+    }
+
+    return '';
+}
+
+
+sub fetch_formatted {
+    my ($self, $ctx) = @_;
+
+    my $media_type = $self->media_type;
+
+    my $formatter;
+    for my $plugin ($self->app->formatter_plugins) {
+        return $plugin->format({
+            context    => $ctx,
+            file       => $self,
+        }) if $plugin->has_format($media_type);
+    }
+
+    return $self->fetch;
+}
+
+
 sub history {
     my $self = shift;
     return $self->log($self->full_path);
@@ -213,6 +242,19 @@ sub diff {
     return $self->diff_blobs($self->full_path, $object_id_1, $object_id_2);
 }
 
+
+sub file_preview {
+    my ($self, %params) = @_;
+
+    Class::MOP::load_class('Yukki::Model::FilePreview');
+    return Yukki::Model::FilePreview->new(
+        %params,
+        app        => $self->app,
+        repository => $self->repository,
+        path       => $self->path,
+    );
+}
+
 1;
 
 __END__
@@ -224,7 +266,7 @@ Yukki::Model::File - the model for loading and saving files in the wiki
 
 =head1 VERSION
 
-version 0.111060
+version 0.111160
 
 =head1 SYNOPSIS
 
@@ -324,6 +366,18 @@ Returns true if the file exists in the repository already.
 
 Returns the contents of the file.
 
+=head2 has_format
+
+  my $yes_or_no = $self->has_format($media_type);
+
+Returns true if the named media type has a format plugin.
+
+=head2 fetch_formatted
+
+  my $html_content = $self->fetch_formatted($ctx);
+
+Returns the contents of the file. If there are any configured formatter plugins for the media type of the file, those will be used to return the file.
+
 =head2 history
 
   my @revisions = $self->history;
@@ -374,6 +428,14 @@ The types are:
     "-"    This chunk was removed in the second revision.
     " "    This chunk is the same in both revisions.
 
+=head2 file_preview
+
+  my $file_preview = $self->file_preview(
+      content => $content,
+  );
+
+Takes this file and returns a L<Yukki::Model::FilePreview> object, with the file contents "replaced" by the given content.
+
 =head1 AUTHOR
 
 Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
