@@ -1,6 +1,6 @@
 package Yukki::Web::Controller::Page;
 BEGIN {
-  $Yukki::Web::Controller::Page::VERSION = '0.111060';
+  $Yukki::Web::Controller::Page::VERSION = '0.111160';
 }
 use 5.12.1;
 use Moose;
@@ -70,12 +70,11 @@ sub view_page {
     my ($repo_name, $path) = $self->repo_name_and_path($ctx);
 
     my $page    = $self->lookup_page($repo_name, $path);
-    my $content = $page->fetch;
 
     my $breadcrumb = $self->breadcrumb($page->repository, $path);
 
     my $body;
-    if (not defined $content) {
+    if (not $page->exists) {
         $body = $self->view('Page')->blank($ctx, { 
             title      => $page->file_name,
             breadcrumb => $breadcrumb,
@@ -90,7 +89,7 @@ sub view_page {
             breadcrumb => $breadcrumb,
             repository => $repo_name,
             page       => $page->full_path, 
-            content    => $content,
+            file       => $page,
         });
     }
 
@@ -125,8 +124,6 @@ sub edit_page {
         return;
     }
 
-    my $content = $page->fetch;
-
     my @attachments = grep { $_->filetype ne 'yukki' } $page->list_files($page->path);
 
     $ctx->response->body( 
@@ -135,7 +132,7 @@ sub edit_page {
             breadcrumb  => $breadcrumb,
             repository  => $repo_name,
             page        => $page->full_path, 
-            content     => $content,
+            file        => $page,
             attachments => \@attachments,
         }) 
     );
@@ -197,6 +194,7 @@ sub preview_page {
     my $breadcrumb = $self->breadcrumb($page->repository, $path);
 
     my $content = $ctx->request->body_parameters->{yukkitext};
+    my $file_preview = $page->file_preview(content => $content);
 
     $ctx->response->body(
         $self->view('Page')->preview($ctx, { 
@@ -204,7 +202,7 @@ sub preview_page {
             breadcrumb => $breadcrumb,
             repository => $repo_name,
             page       => $page->full_path,
-            content    => $content,
+            file       => $file_preview,
         })
     );
 }
@@ -266,7 +264,7 @@ Yukki::Web::Controller::Page - controller for viewing and editing pages
 
 =head1 VERSION
 
-version 0.111060
+version 0.111160
 
 =head1 DESCRIPTION
 
