@@ -1,20 +1,15 @@
 package Yukki::Web::Plugin;
-$Yukki::Web::Plugin::VERSION = '0.991_007'; # TRIAL
-$Yukki::Web::Plugin::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo;
-
-use Type::Utils;
-
-use namespace::clean;
-
+BEGIN {
+  $Yukki::Web::Plugin::VERSION = '0.111160';
+}
+use 5.12.1;
+use Moose;
 # ABSTRACT:  base class for Yukki plugins
 
 
 has app => (
     is          => 'ro',
-    isa         => class_type('Yukki::Web'),
+    isa         => 'Yukki::Web',
     required    => 1,
     weak_ref    => 1,
     handles     => 'Yukki::Role::App',
@@ -23,32 +18,27 @@ has app => (
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Yukki::Web::Plugin - base class for Yukki plugins
 
 =head1 VERSION
 
-version 0.991_007
+version 0.111160
 
 =head1 SYNOPSIS
 
   package MyPlugins::LowerCase;
   use 5.12.1;
-  use Moo;
-
-  use Types::Standard qw( HashRef CodeRef );
+  use Moose;
 
   extends 'Yukki::Web::Plugin';
 
   has format_helpers => (
       is          => 'ro',
-      isa         => HashRef[CodeRef],
+      isa         => 'HashRef[CodeRef]',
       default     => sub { +{
           'lc' => \&lc_helper,
       } },
@@ -56,7 +46,7 @@ version 0.991_007
 
   with 'Yukki::Web::Plugin::Role::FormatHelper';
 
-  sub lc_helper {
+  sub lc_helper { 
       my ($params) = @_;
       return lc $params->{arg};
   }
@@ -89,9 +79,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
