@@ -1,13 +1,9 @@
 package Yukki::Web::Plugin::Attachment;
-$Yukki::Web::Plugin::Attachment::VERSION = '0.991_007'; # TRIAL
-$Yukki::Web::Plugin::Attachment::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo;
-
-use Types::Standard qw( HashRef Str );
-
-use namespace::clean;
+BEGIN {
+  $Yukki::Web::Plugin::Attachment::VERSION = '0.111160';
+}
+use 5.12.1;
+use Moose;
 
 extends 'Yukki::Web::Plugin';
 
@@ -18,7 +14,7 @@ use URI::Escape qw( uri_escape );
 
 has format_helpers => (
     is          => 'ro',
-    isa         => HashRef[Str],
+    isa         => 'HashRef[Str]',
     required    => 1,
     default     => sub { +{
         'attachment' => 'attachment_url',
@@ -69,18 +65,15 @@ sub attachment_url {
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Yukki::Web::Plugin::Attachment - plugin for attachments
 
 =head1 VERSION
 
-version 0.991_007
+version 0.111160
 
 =head1 SYNOPSIS
 
@@ -108,9 +101,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
