@@ -1,10 +1,9 @@
 package Yukki::Web::Plugin::Role::FormatHelper;
-$Yukki::Web::Plugin::Role::FormatHelper::VERSION = '0.991_007'; # TRIAL
-$Yukki::Web::Plugin::Role::FormatHelper::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo::Role;
-
+BEGIN {
+  $Yukki::Web::Plugin::Role::FormatHelper::VERSION = '0.111160';
+}
+use 5.12.1;
+use Moose::Role;
 # ABSTRACT: interface for quick format helpers
 
 
@@ -13,32 +12,27 @@ requires qw( format_helpers );
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Yukki::Web::Plugin::Role::FormatHelper - interface for quick format helpers
 
 =head1 VERSION
 
-version 0.991_007
+version 0.111160
 
 =head1 SYNOPSIS
 
   package MyPlugins::LowerCase;
   use 5.12.1;
-  use Moo;
-
-  use Types::Standard qw( HashRef Str );
+  use Moose;
 
   extends 'Yukki::Web::Plugin';
 
   has format_helpers => (
       is          => 'ro',
-      isa         => HashRef[Str],
+      isa         => 'HashRef[Str]',
       default     => sub { +{
           'lc' => 'lc_helper',
       } },
@@ -46,7 +40,7 @@ version 0.991_007
 
   with 'Yukki::Web::Plugin::Role::FormatHelper';
 
-  sub lc_helper {
+  sub lc_helper { 
       my ($self, $params) = @_;
       return lc $params->{arg};
   }
@@ -97,9 +91,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
