@@ -1,9 +1,9 @@
 package Yukki::Web::Plugin::Role::Formatter;
-$Yukki::Web::Plugin::Role::Formatter::VERSION = '0.991_007'; # TRIAL
-$Yukki::Web::Plugin::Role::Formatter::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo::Role;
+BEGIN {
+  $Yukki::Web::Plugin::Role::Formatter::VERSION = '0.111160';
+}
+use 5.12.1;
+use Moose::Role;
 
 # ABSTRACT: interface for HTML formatters
 
@@ -31,32 +31,27 @@ sub format {
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Yukki::Web::Plugin::Role::Formatter - interface for HTML formatters
 
 =head1 VERSION
 
-version 0.991_007
+version 0.111160
 
 =head1 SYNOPSIS
 
   package MyPlugins::SimpleText;
   use 5.12.1;
-  use Moo;
-
-  use Types::Standard qw( HashRef Str );
+  use Moose;
 
   extends 'Yukki::Web::Plugin';
 
   has html_formatters => (
       is          => 'ro',
-      isa         => HashRef[Str],
+      isa         => 'HashRef[Str]',
       default     => sub { +{
           'text/simple' => 'format_simple',
         } },
@@ -69,7 +64,7 @@ version 0.991_007
 
       my $html = $file->fetch;
       $html =~ s/$/<br>/g;
-
+      
       return [ { title => 'Simple' }, $html ];
   }
 
@@ -138,9 +133,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
