@@ -1,13 +1,9 @@
 package Yukki::Web::Plugin::Spreadsheet;
-$Yukki::Web::Plugin::Spreadsheet::VERSION = '0.991_007'; # TRIAL
-$Yukki::Web::Plugin::Spreadsheet::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo;
-
-use Types::Standard qw( HashRef Str );
-
-use namespace::clean;
+BEGIN {
+  $Yukki::Web::Plugin::Spreadsheet::VERSION = '0.111160';
+}
+use 5.12.1;
+use Moose;
 
 extends 'Yukki::Web::Plugin';
 
@@ -15,12 +11,12 @@ extends 'Yukki::Web::Plugin';
 
 use Scalar::Util qw( blessed );
 use Try::Tiny;
-use Yukki::Error qw( http_throw );
+use Yukki::Error;
 
 
 has format_helpers => (
     is          => 'ro',
-    isa         => HashRef[Str],
+    isa         => 'HashRef[Str]',
     required    => 1,
     default     => sub { +{
         '=' => 'spreadsheet_eval',
@@ -45,7 +41,7 @@ sub initialize_context {
 
 sub setup_spreadsheet {
     my ($self, $params) = @_;
-
+    
     my $ctx  = $params->{context};
     my $file = $params->{file};
     my $arg  = $params->{arg};
@@ -80,7 +76,7 @@ sub cell {
     my $map = $ctx->stash->{'Spreadsheet.map'};
     $map->{ $file->repository_name }{ $file->full_path }{ $name } = $new_cell
         if defined $new_cell;
-    return $map->{ $file->repository_name }{ $file->full_path }{ $name };
+    return $map->{ $file->repository_name }{ $file->full_path }{ $name }; 
 }
 
 
@@ -104,7 +100,7 @@ sub lookup_name {
 
         $path = $self->app->munge_label($path);
 
-        my $other_repo = $self->model('Repository', {
+        my $other_repo = $self->model('Repository', { 
             name => $repository_name,
         });
 
@@ -112,16 +108,14 @@ sub lookup_name {
             full_path => $path,
         });
 
-        $self->load_spreadsheet($ctx, $other_file)
-            unless $other_file->repository_name eq $file->repository_name
-               and $other_file->full_path       eq $file->full_path;;
+        $self->load_spreadsheet($ctx, $other_file);
 
         return $self->cell($ctx, $other_file, $name);
     }
 
     my $cell = $self->cell($ctx, $file, $name);
 
-    http_throw('unknown name') if not defined $cell;
+    Yukki::Error->throw('unknown name') if not defined $cell;
 
     return $cell;
 }
@@ -131,11 +125,12 @@ sub spreadsheet_eval {
     my ($self, $params) = @_;
 
     my $ctx         = $params->{context};
+    my $plugin_name = $params->{plugin_name};
     my $file        = $params->{file};
     my $arg         = $params->{arg};
 
     my $sheet = $self->initialize_context($ctx);
-
+   
     my ($new_cell, $name, $formula) = $self->setup_spreadsheet($params);
 
     my $error = 0;
@@ -143,7 +138,7 @@ sub spreadsheet_eval {
     try {
         $formula =~ s/ \[ ([^\]]+) \] /
             $self->lookup_name({
-                %$params,
+                %$params, 
                 name => $1,
             })
         /gex;
@@ -172,7 +167,7 @@ sub spreadsheet_eval {
         $value  = $raw->{cellerrors}{ $new_cell };
     }
     else {
-        $attrs .= qq[ title="$arg" class="spreadsheet-cell"];
+        $attrs .= qq[ title="$arg" class="spreadsheet-cell error" ];
         $value = $raw->{datavalues}{ $new_cell };
     }
 
@@ -182,25 +177,22 @@ sub spreadsheet_eval {
 
 sub load_spreadsheet {
     my ($self, $ctx, $file) = @_;
-    http_throw('no such spreadsheet exists') unless $file->exists;
+    Yukki::Error->throw('no such spreadsheet exists') unless $file->exists;
     $file->fetch_formatted($ctx);
 }
 
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Yukki::Web::Plugin::Spreadsheet - add spreadsheet functionality to wiki pages
 
 =head1 VERSION
 
-version 0.991_007
+version 0.111160
 
 =head1 SYNOPSIS
 
@@ -256,9 +248,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
