@@ -1,12 +1,9 @@
 package Yukki::Web::Plugin::YukkiText;
-$Yukki::Web::Plugin::YukkiText::VERSION = '0.991_007'; # TRIAL
-$Yukki::Web::Plugin::YukkiText::VERSION = '0.991007';
-use v5.24;
-use utf8;
-use Moo;
-
-use Type::Utils;
-use Types::Standard qw( HashRef Str );
+BEGIN {
+  $Yukki::Web::Plugin::YukkiText::VERSION = '0.111160';
+}
+use 5.12.1;
+use Moose;
 
 extends 'Yukki::Web::Plugin';
 
@@ -15,12 +12,10 @@ extends 'Yukki::Web::Plugin';
 use Text::MultiMarkdown;
 use Try::Tiny;
 
-use namespace::clean;
-
 
 has html_formatters => (
     is          => 'ro',
-    isa         => HashRef[Str],
+    isa         => 'HashRef[Str]',
     required    => 1,
     default     => sub { +{
         'text/yukki'    => 'yukkitext',
@@ -32,10 +27,9 @@ with 'Yukki::Web::Plugin::Role::Formatter';
 
 has markdown => (
     is          => 'ro',
-    isa         => class_type('Text::MultiMarkdown'),
+    isa         => 'Text::MultiMarkdown',
     required    => 1,
-    lazy        => 1,
-    builder     => '_build_markdown',
+    lazy_build  => 1,
     handles     => {
         'format_markdown' => 'markdown',
     },
@@ -45,7 +39,6 @@ sub _build_markdown {
     Text::MultiMarkdown->new(
         markdown_in_html_blocks => 1,
         heading_ids             => 0,
-        strip_metadata          => 1,
     );
 }
 
@@ -66,7 +59,7 @@ sub yukkilink {
         $repository = $repo_name;
         $link       = $local_link;
     }
-
+    
     # If we did not get a label, make the label into the link
     if (not defined $label) {
         ($label) = $link =~ m{([^/]+)$};
@@ -117,7 +110,7 @@ sub yukkiplugin {
                     arg         => $arg,
                 });
             }
-
+            
             catch {
                 warn "Plugin Error: $_";
             };
@@ -135,15 +128,11 @@ sub yukkitext {
     my ($self, $params) = @_;
 
     my $file       = $params->{file};
-    my $position   = 0 + ($params->{position} // -1);
     my $repository = $file->repository_name;
-    my $yukkitext  = $file->fetch // '';
-
-    $yukkitext =~ s[(.{$position}.*?)$][$1<span id="yukkitext-caret"></span>]sm
-        if $position >= 0;
+    my $yukkitext  = $file->fetch;
 
     # Yukki Links
-    $yukkitext =~ s{
+    $yukkitext =~ s{ 
         (?<!\\)                 # \ will escape the link
         \[\[ \s*                # [[ to start it
 
@@ -155,18 +144,18 @@ sub yukkitext {
             )?                  # is optional
 
         \]\]                    # ]] to end
-    }{
-        $self->yukkilink({
-            %$params,
-
-            repository => $1 // $repository,
-            link       => $2,
+    }{ 
+        $self->yukkilink({ 
+            %$params, 
+            
+            repository => $1 // $repository, 
+            link       => $2, 
             label      => $3,
         });
     }xeg;
 
     # Handle escaped links, hide the escape
-    $yukkitext =~ s{
+    $yukkitext =~ s{ 
         \\                      # \ will escape the link
         (\[\[ \s*               # [[ to start it
 
@@ -197,7 +186,7 @@ sub yukkitext {
             plugin_name => $1,
             arg         => $2,
         });
-   }xegms;
+    }xeg;
 
     # Handle the escaped plugin thing
     $yukkitext =~ s{
@@ -209,32 +198,23 @@ sub yukkitext {
             .*?                 # plugin arguments
 
         \}\})                   # }} to end
-    }{$1}xgms;
+    }{$1}xg;
 
-    my $formatted = '<div>' . $self->format_markdown($yukkitext) . '</div>';
-
-    # Just in case markdown mangled the caret marker:
-    $formatted =~ s[&lt;span id="yukkitext-caret"&gt;&lt;/span&gt;]
-                   [<span id="yukkitext-caret"></span>];
-
-    return $formatted;
+    return '<div>' . $self->format_markdown($yukkitext) . '</div>';
 }
 
 1;
 
 __END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Yukki::Web::Plugin::YukkiText - format text/yukki files using markdown, etc.
 
 =head1 VERSION
 
-version 0.991_007
+version 0.111160
 
 =head1 SYNOPSIS
 
@@ -306,9 +286,10 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Qubling Software LLC.
+This software is copyright (c) 2011 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
